pub struct AlignerWithRef { /* private fields */ }Expand description
Aligner with reference sequence for proper SW scoring
This aligner extracts reference sequences from the index and uses them for Smith-Waterman alignment, giving accurate scores for matches/mismatches.
Implementations
Sourceimpl AlignerWithRef
impl AlignerWithRef
Sourcepub fn new(index_with_ref: EbwtWithRef, params: AlignerParams) -> Self
pub fn new(index_with_ref: EbwtWithRef, params: AlignerParams) -> Self
Create a new aligner with reference
Sourcepub fn align(&self, read: &[Nuc], read_rc: &[Nuc]) -> AlignmentResult
pub fn align(&self, read: &[Nuc], read_rc: &[Nuc]) -> AlignmentResult
Align a single read using actual reference sequences
Searches both forward and reverse complement strands and returns all valid alignments with scores computed against actual reference.
Sourcepub fn index(&self) -> &EbwtWithRef
pub fn index(&self) -> &EbwtWithRef
Get the underlying EbwtWithRef