SeedAligner

Struct SeedAligner 

pub struct SeedAligner { /* private fields */ }
Seed aligner that searches for seed matches

Implementations

Source

impl SeedAligner

pub fn new(policy: SeedPolicy) -> Self

Create a new seed aligner

pub fn with_seed_sets(policy: SeedPolicy, seed_sets: usize) -> Self

Create a seed aligner with custom number of seed sets

pub fn search<I: FmIndex>( &mut self, index: &I, read: &[Nuc], ) -> Result<SeedResults>

Search for seeds in a read using multiple seed sets

This implements a multi-set seed search. If the first seed set finds no matches, it tries additional sets with different offsets to handle reads with SNPs that break some seeds.